@@ -61,9 +61,6 @@ Application.prototype = {
         Gettext.textdomain('gnome-documents');
         GLib.set_prgname('gnome-documents');
 
-        GLib.setenv('GJS_DEBUG_OUTPUT', 'stderr', true);
-        GLib.setenv('GJS_DEBUG_TOPICS', 'JS ERROR;JS LOG', true);
-
         Global.settings = new Gio.Settings({ schema: 'org.gnome.documents' });
 
         // TODO: subclass Gtk.Application once we support GObject inheritance,
@@ -72,7 +69,7 @@ Application.prototype = {
             application_id: 'org.gnome.Documents',
             flags: Gio.ApplicationFlags.HANDLES_COMMAND_LINE
         });
-        GLib.set_prgname('gnome-documents');
+
         this.application.connect('startup', Lang.bind(this, this._onStartup));
         this.application.connect('command-line', Lang.bind(this, this._commandLine));
         this.application.connect('activate', Lang.bind(this,
@@ -101,16 +98,17 @@ Application.prototype = {
             }));
         this.application.add_action(fsAction);
 
+        /* FIXME: use GSettings.create_action() once it's introspectable */
         let viewAsAction = Gio.SimpleAction.new_stateful('view-as',
                                                          GLib.VariantType.new('s'),
-                                                         Utils.listSettingToMenu());
+                                                         Global.settings.get_value('view-as'));
         viewAsAction.connect('activate', Lang.bind(this,
             function(action, variant) {
-                Global.settings.set_boolean('list-view', Utils.listMenuToSetting(variant));
+                Global.settings.set_value('view-as', variant);
             }));
-        Global.settings.connect('changed::list-view', Lang.bind(this,
+        Global.settings.connect('changed::view-as', Lang.bind(this,
             function() {
-                viewAsAction.state = Utils.listSettingToMenu();
+                viewAsAction.state = Global.settings.get_value('view-as');
             }));
         this.application.add_action(viewAsAction);
 
@@ -119,7 +117,7 @@ Application.prototype = {
 	menu.append(_("Quit"), 'app.quit');
 
         let viewAs = new Gio.Menu();
-        viewAs.append(_("Grid"), 'app.view-as::grid');
+        viewAs.append(_("Grid"), 'app.view-as::icon');
         viewAs.append(_("List"), 'app.view-as::list');
         menu.prepend_section(_("View as"), viewAs);
 
